#
# spec file for package raspberrypi-firmware-config
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           raspberrypi-firmware-config
Version:        2023.04.25
Release:        2.1
Summary:        Configuration for the Raspberry Pi firmware loader
License:        MIT
Group:          System/Boot
URL:            https://github.com/raspberrypi/firmware/
Source:         config.txt
BuildRequires:  raspberrypi-firmware
Requires:       raspberrypi-firmware = %{version}
Supplements:    modalias(of:NfirmwareT*Craspberrypi%2Cbcm2835-firmwareC*)
Conflicts:      kernel < 4.12.14
%if "%{name}" == "raspberrypi-firmware-config-camera"
Conflicts:      raspberrypi-firmware-config
Requires:       (raspberrypi-firmware-extra or raspberrypi-firmware-extra-pi4)
%else
Conflicts:      raspberrypi-firmware-config-camera
%endif
Provides:       raspberrypi-firmware-branding-openSUSE = %{version}
Obsoletes:      raspberrypi-firmware-branding-openSUSE < %{version}
Provides:       raspberrypi-firmware-config = %{version}
Provides:       raspberrypi-firmware-config-rpi = %{version}
Obsoletes:      raspberrypi-firmware-config-rpi < %{version}
Provides:       raspberrypi-firmware-config-rpi0w = %{version}
Obsoletes:      raspberrypi-firmware-config-rpi0w < %{version}
Provides:       raspberrypi-firmware-config-rpi2 = %{version}
Obsoletes:      raspberrypi-firmware-config-rpi2 < %{version}
Provides:       raspberrypi-firmware-config-rpi3 = %{version}
Obsoletes:      raspberrypi-firmware-config-rpi3 < %{version}
BuildArch:      noarch

%description
This package configures the Raspberry Pi boot process.
2 flavors are available:
  * raspberrypi-firmware-config - the default config
  * raspberrypi-firmware-config-camera - the config which enables
  start_x=1 and increase gpu_mem to be able to use a camera module

Note: config.txt should not be used to set manually params (gpu_mem, etc.)
please create extraconfig.txt instead.

%prep

%build

%install
install -D -p -m 0644 %{SOURCE0} %{buildroot}/boot/vc/config.txt
%if "%{name}" == "raspberrypi-firmware-config-camera"
sed -i "s/gpu_mem=32/# gpu_mem=32/" %{buildroot}/boot/vc/config.txt
sed -i "s/# start_x=1/start_x=1/" %{buildroot}/boot/vc/config.txt
sed -i "s/# gpu_mem=128/gpu_mem=128/" %{buildroot}/boot/vc/config.txt
%endif

%post
if mountpoint -q /boot/efi && [ ! -L /boot/efi ]; then
  [ -f /boot/efi/config.txt ] && cp /boot/efi/config.txt /boot/efi/config.txt.rpmsave
  cp /boot/vc/config.txt /boot/efi/config.txt
fi

%files
%defattr(-,root,root)
%config /boot/vc/config.txt

%changelog
* Thu Apr 27 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 543692d23 (2023-04-25):
  * firmware: arm_loader: Set local-bd-address if 6 zeroes found
  * firmware: arm_loader: Really check for a zero local-bd-address
    See: raspberrypi/linux#5437
  * firmware: arm_dt: Don't overwrite existing i2c aliases
    See: raspberrypi/linux#5428
  * firmware: arm_loader: Reduce CMA warning severity
    See: #1807
* Wed Apr  5 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to c4122b870 (2023-03-22):
  * firmware: gencmd: Add a fallback to mailbox interface if vchiq is not available
  * firmware: Handle 64-bitness of named kernels
    See: #1792
  * firmware: bootloader: Fix automatic 64bit selection on Pi3s
    See: https://forums.raspberrypi.com/viewtopic.php?p=2089764#p2089764
  * firmware: bootloader: Raise CMA cap to 512MB on a 64-bit Pi4
  * firmware: bootloader: Prefer 64-bit kernels on Pi 4s
    See: https://forums.raspberrypi.com/viewtopic.php?p=2088935#p2088935
  * firmware: platform: clocks: Replace m2mc with hdmi for state machine clock on 2711
* Fri Mar  3 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 489d3e2d0 (2023-02-22):
  * firmware: video_decode: Convert the active lines, not the padded buffer
  * firmware: il isp: Correct histogram masks for updated group
    2 regions
* Thu Jan 19 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2578acb89 (2023-01-18):
  * kernel: overlays: i2c-sensor: Add mpu6050 and mpu9250
    See: raspberrypi/linux#5325
  * firmware: arm_dispmanx: Correct support for NV21, and add support for YV16
    See: #1767
  * firmware: arm_dispmanx: Fix FKMS to adopt pre-multiplied alpha
    See: #1773
  * firmware: hdmi_2711: Make some clock setup unconditional so booting
    without hdmi setup is possible
    See: https://forums.raspberrypi.com/viewtopic.php?t=345362
  * firmware: Actually rebuild firmware described in previous commit
  * firmware: Add D flag to video= cmdline option when hotplug is forced
    See: https://forums.raspberrypi.com/viewtopic.php?p=2067109#p2067109
* Fri Dec 23 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0a7ea702 (2022-12-12):
  * firmware: arm_loader: PWM1 is not available on GPIO 45
  * firmware: power: Always read the uncached voltage for AIN and USB_PD
    See: https://forums.raspberrypi.com/viewtopic.php?p=2059832#p2059832
  * firmware: Use new SDHCI controller instead of legacy arasan
    See: #1763
* Mon Nov 21 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to b8a7365 (2022-11-18):
  * firmware: arm_loader: Improvements to Compute Module audio
    See: https://forums.raspberrypi.com/viewtopic.php?p=2052680
  * firmware: arm_loader: Fix GPIO bank 1 support
    See: #1756
* Thu Oct 27 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 13691cee9 (2022-10-26):
  * firmware: arm_loader: Add vcmailbox support for 256bit OTP
    customer device key
    See: raspberrypi/usbboot#163
  * firmware: il: video_encode: MJPEG is not conditional on
    being RASPBERRYPI_FULL
* Wed Oct 19 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to ab37ef59f (2022-10-18):
  * firmware: ldconfig: Add all, none, tryboot section support
    to autoboot.txt for start.elf
  * firmware: arm-dt: bootloader: Pass the original partition
    number when booting a ramdisk
  * firmware: arm_loader: HAT EEPROM support for GPIO bank 1
    See: #1756
* Tue Oct 18 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to bfbd42ef2 (2022-10-14):
  * firmware: isp: Run ISP without hi-res output buffer
  * firmware: arm_dt: Export the bootloader EEPROM RSA public
    key via device-tree
  * firmware: Add tryboot A_B mode
  * firmware: il: isp: Correct order buffers were returned in
  * firmware: board_info: Fix Pi 400 PHY addresses
    See: #1754
* Tue Oct  4 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2b3cef2f4 (2022-09-30):
  * firmware: isp: Workaround for very unpleasant artifacts in the
    sharpening block
  * firmware: arm_loader: Raise maximum gzipped kernel size
  * firmware: arm-loader: Indicate tryboot status via /proc/device-tree/chosen/bootloader/tryboot
  * firmware: arm_loader: Increase TFTP block size to 1468 bytes
    See: raspberrypi/rpi-eeprom#375
  * firmware: Add kernel= logging
  * firmware: camera_auto_detect changes
    See: #1750
  * firmware: Fix USB boot
    See: #1744
  * firmware: video decode/MJPEG fixes
    See: http://git/vc4/vc4/-/merge_requests/1548
  * firmware: power: Restore VEC and PIXEL clocks after HDMI domain power cycle
    See: raspberrypi/linux#4962
  * firmware: arm_loader: Never set warranty bit
    See: #1741
  * firmware: vcfw: camera_subsystem: Fix loop counter for powering up devices
    See: https://forums.raspberrypi.com/viewtopic.php?t=338917
  * firmware: ldconfig: Add [cm4s] conditional
  * firmware: platform: Set min_frequency for HDMI SM clock on Pi0-3
  * firmware: power: Fix failover to secondary PMIC interface functions
    See: https://forums.raspberrypi.com/viewtopic.php?t=338429
  * firmware: arm_loader: Correct GPIO expander initial state via SET_GPIO_CONFIG
    See: raspberrypi/linux#5107
  * firmware: Disable BT flow control pins for Pi3 rev1.3
  * firmware: arm_loader: initramfs over NVME fix
    See: #1731
  * firmware: arm-dt: Export log buffer addresses to /proc/chosen/log
  * firmware: arm_loader: Fix GET_CLOCKS to not overwrite client buffer
    See: #1688
  * firmware: arm_loader: Declare program_sdhost_use_dma
* Fri Jul  8 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to df569e0 (2022-07-04):
  * firmware: video_decode: Stop decode on a colourspace change
    See: raspberrypi/linux#5059
  * firmware: video_encode: Fix subsample image alignment assert
  * firmware: tc358762_DSI: Don't start the PV and DSI before the HVS
  * firmware: hello_pi: Fix some build issues
    See: #1728
  * firmware: arm_dt: camera_auto_detect cam0 flag needs to
    look at Unicam instance, not port
  * firmware: platform: over-voltage Zero 2 W by two pips
    See: #1723
  * firmware: arm_loader_dvfs: Only add clocks to boostable list
    when they have been boosted
    See: #1726
  * firmware: arm_dt: Try upstream DTB files if downstream absent
  * firmware: arm_loader: Delay the USB controller switchover
  * firmware: Fix for vc_image YUYV family to YUV422 planar conversion function
  * firmware: vcgencmd display_power and camera_auto_detect fixes
  * firmware: variants: Add mjpg_encode to the standard firmware image
  * firmware: arm_loader_dvfs: Support CLOCK_HDMI as boostable clock
    See: raspberrypi/linux#5016
  * firmware: dtblob: Use a cached alias to reduce boot time
  * firmware: hdmi: Reduce the number of EDID retries if hotplug is not detected
  * firmware: arm_loader: Support longer file paths
    See: #1720
  * firmware: arm_loader_dvfs: Make arm only see its own boosts,
    fixed and min clocks
  * firmware: dtoverlay: Fix path rebasing and exports
  * firmware: dtoverlay: Fix clang warnings
  * firmware: dtoverlay: Add support for string escape sequences
    See: https://forums.raspberrypi.com/viewtopic.php?t=330792
  * firmware: isp: R and B order must be swapped when reading
    VC_IMAGE_RGBA32 into the ISP
    See: http://git/vc4/vc4/-/merge_requests/1430
* Fri Mar  4 2022 Martin Wilck <mwilck@suse.com>
- Install modprobe.conf files to %%_modprobedir (bsc#1196275, jsc#SLE-20639)
* Wed Mar  2 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 231daece7c (2022-03-01):
  * firmware: board_info: Handle misprogrammed 3B rev 1.2s
  * firmware: mmal: Add mapping for IL OMX_IndexParamBrcmEnableIJGTableScaling param
  * firmware: Handle overlay parameters embedded in overlay_map.dtb
    See: raspberrypi/linux#4860
  * firmware: firmware: Add HDMI_PORTS trait
  * firmware: arm_dt: Fix rpi-poe overlay parameters
    See: #1689
  * firmware: jpeghw: Skip APP0 AVI1 headers, regardless of length
    See: https://forums.raspberrypi.com/viewtopic.php?p=1975448
  * firmware: camera_subsystem: Report ignored interfaces due to libcamera
    See: #1679
  * firmware: Export os_prefix, overlay_prefix, rsts and boot-mode on all models
  * firmware: vcfw/hdmi_i2c: Initialise all instances from hdmi_i2c_init
  * firmware: mmal: Add mapping for IL OMX_IndexParamBrcmEnableIJGTableScaling param
    See: raspberrypi/linux#4669
* Tue Jan 25 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 9c04ed2c1a (2022-01-24):
  * firmware: platform: Limit max clock-id to CLOCK_VEC for now
    See: #1688
* Mon Jan 24 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 827fdd0736 (2022-01-20):
  * firmware: dtoverlay: Don't mix non-fatal errors and offsets
    See: #1686
  * firmware: arm_loader: Load vl805 overlay on CM4
    See: https://forums.raspberrypi.com/viewtopic.php?t=326088
  * firmware: gencmdserv: Add mailbox interface to gencmd
  * firmware: improve firmware camera detection
  * firmware: arm-loader: Fix kernel8.img selection on 2837 with arm_64bit=1
    See: #1671
  * firmware: ldconfig: Discard subsequent chunks from a truncated line
    See: #1669
  * firmware: cec: Fail set_passive_mode when running with kms
  * firmware: Firmware: Remove PWM/audio traits for CM4
  * firmware: usb: Fix non-BCM2711 MSD support
    See: raspberrypi/usbboot#102
* Wed Dec 22 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1a0297bfbf (2021-12-01):
  * firmware: board_info: Add upstream dtb names for cm1 & 3
  * firmware: board_info: Add upstream dtb name for cm4
    See: #1660
  * firmware: platform: Allow users to disable camera boot HMAC check
    See: #1657
  * firmware: clock: 2711: Fix potential API issue in 2711 VCO setup
  * firmware: arm_loader: Enable USB MSD boot mode on Zero 2 W
  * firmware: isp: Fix Rec.709 colour space problems
* Mon Nov 22 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix deps for raspberrypi-firmware-config and raspberrypi-firmware-config-camera
* Wed Nov 17 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add raspberrypi-firmware-config-camera flavor - boo#1192047
* Wed Nov 17 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 12bc6e3677 (2021-11-16):
  * firmware: dtoverlay: Rebase aliases in overlays like labels
  * firmware: isp: Set core/vpu min clock to 320Mhz during ISP operation
  * firmware: arm_loader: Enable watchdog early if wanted
    See: #1651
  * firmware: hello_fft: Update outdated link to V3D spec
  * firmware: hello_fft: Remove unused function declaration
    See: #1645
    See: raspberrypi/userland#710
  * firmware: platform: Declare CM4's SIO_1V8_SEL and SD_PWR_ON
    See: raspberrypi/Raspberry-Pi-OS-64bit#188
  * firmware: platform: Fix incorrect turbo voltage scaling on Pi0
    See: raspberrypi/documentation#2255
  * firmware: ISP: Fix magenta colour in right hand image of stereo pair
    See: https://forums.raspberrypi.com/viewtopic.php?t=321089
  * firmware: platform: Remove licence on VP6, VP8, Theora, and FLAC
    See: raspberrypi/linux#4661
  * firmware: arm_loader: Allow VEC clock to be controlled by arm
  * firmware: userland: Reduce debug_sym error messages
    See: https://forums.raspberrypi.com/viewtopic.php?f=98&t=322238
  * firmware: arm_dt: Increase maximum line length to 98
    See: raspberrypi/linux#4638
  * firmware: video_decode: i/p port enable/disable without o/p active could stall
    See: RPi-Distro/vlc#48
    See: Hexxeh/rpi-firmware#272
    See: #1637
  * firmware: clock-2711: Limit PLLB VCO frequency to the high range
  * firmware: arm_dt: Export the boot-mode, partition and usb state via device-tree
    See: #1621
* Tue Oct  5 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to b5257da58c (2021-09-30):
  * firmware: arm_loader: Allow non-optional reads of current clock
    See: #1619
  * firmware: dispmanx: Demote null eptr from vcos_verify to no warning
    See: raspberrypi/linux#4592
  * firmware: filesystem: sdcard: Probe FAT type in GPT ESD partitions
  * firmware: tvservice: Add check to warn when running with kms
  * firmware: filesystem: sdcard: Fix Hybrid GPT partitions
    See: #1465
  * firmware: video_decode: Ensure all buffers are flushed before
    port disable completes
  * firmware: arm_loader: Allow hvs interrupt during SET_NOTIFY_DISPLAY_DONE
  * firmware: arm_display: Allow null buffer in successful call
    See: raspberrypi/linux#4540
* Tue Sep 14 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to b80f36b3fb (2021-09-13):
  * firmware: hdmi_2711: Use HDMI block REPEAT_PIXEL instead of PV
    See: https://forum.libreelec.tv/thread/24415-le-10-beta-for-i4-force-hdmi-resolution
  * firmware: DSI display autodetection for kms
  * firmware: arm_dt: Load overlays for detected cameras
  * firmware: Make more use of the user-warnings DT property
  * firmware: arm_loader: Consider required flags from GET_CLOCK_RATE
    See: #1598
  * firmware: arm_loader: Make most arm clock requests required
    See: #1598
  * firmware: firmware: Disable VLL loading from file system
    See: #1605
  * firmware: video_decode: Use the ISP instead of vc_image_convert
  * firmware: video_decode: Correct support for YVU formats using ISP
  * firmware: arm_dt: Limit CMA to 256MB if total_mem < 2GB or gpu_mem > 256MB
    See: #1603
  * firmware: hdmi_cec: Remove TX/RX SW_INIT on power_on
    See: Hexxeh/rpi-firmware#267
    See: https://www.raspberrypi.org/forums/viewtopic.php?p=1895082#p1895082
  * firmware: cec: Avoid sending messages with kms
    See: raspberrypi/linux#4460
  * firmware: Revert: video_decode: Use the ISP instead of vc_image_convert
  * firmware: isp: Set the YUV420/YVU420 format stride to 64 byte
  * arm_loader: Add message to release firmware framebuffer
  * firmware: video_decode: Use the ISP instead of vc_image_convert
  * firmware: hdmi-2711: Wait for HDMI hardware scheduler to activate in HDMI mode
  * firmware: bcm_host: Recognise all Pi 4 variants, add BCM2711
    See: raspberrypi/userland#695
  * firmware: PoE+ HAT support
    See: raspberrypi/linux#4367
  * firmware: arm_loader: Use Pi4 bootloader MAC_ADDRESS if set
  * firmware: platform: Apply ARM thermal throttling rules on BCM2711
  * firmware: dt-blob.dts: Correct HDMI HPD and EMMC_ENABLE for CM4
    See: https://www.raspberrypi.org/forums/viewtopic.php?f=29&p=1858516
  * firmware: vcfw/hdmi: CUSTOM modes used for FKMS didn't set RGB quant range correctly
    See: #1580
  * firmware: platform: Remove build-time constant for MICROVOLTS_PER_PIP
  * firmware: Pi400: Reduce MII clock freq when probing ethernet PHY
  * firmware: isp: Ensure the VRF is locked when setting up video colour denoise
    See: raspberrypi/libcamera-apps#19
  * firmware: isp: Remove custom EV mappings from camera tunings
  * firmware: Add support for board-type=0xXX conditional filters in bootloader, bootcode and firmware
  * firmware: Two UART1 patches
    See: #1566
  * firmware: arm_loader: kernel_old=1 should force kernel_address=0
    See: #1561
  * firmware: scalerlib: Fix offset applied to x coordinate of YUV10COL image
    See: https://forum.kodi.tv/showthread.php?tid=361164&pid=3024654#pid3024654
  * firmware: vcfw/power: Add a new latch for power_pad_control
    See: #1552
  * firmware: board-info: Fix memsize on 3B+
  * firmware: Move core to PLLA and support accurate clk108
    See: xbmc/xbmc#19263
  * firmware: board_info: Separate memory size from OTP field encoding
  * firmware: power: Swap DA9090 ADC assignments to match XR77004
  * firmware: vl805: Remove redundant log statement and fix warning
  * firmware: power: Fix DA9090 ADC1 register definition
  * firmware: arm_loader: Only report clocks arm has set, not siblings
  * firmware: arm_loader: Don't report clocks set as turbo side effect of arm clock
  * firmware: arm_loader: 2711: gpu clocks are not dependant
  * firmware: platform: Need to clear cached versions of get_max_clock_internal vars
  * firmware: video_decode: For VC1/WMV with no signalled header bytes, use start of 1st buffer
  See: raspberrypi/linux#4113
* Fri Apr  9 2021 Matthias Brugger <mbrugger@suse.com>
- Use smbios overlay to get minimal SMBIOS information through dmidecode (bsc#1183079)
* Tue Mar 16 2021 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Fix previous change. No need to set DWC2 in host mode. OTG works fine on
  production CM4 IO boards. It was being tested earlier on a pre-release
  development board. (bsc#1183241)
- Run pre_checkin.sh, which fixed some style issues.
* Mon Mar 15 2021 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Set CM4's DWC2 in host mode by default (bsc#1183241)
* Fri Mar 12 2021 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Update to 0591568b29 (2021-03-10) (bsc#1183444):
  * firmware: video_decode lockup handling
  * firmware: isp: Initialise extras to avoid vpitch being random
  * firmware: usb: Fix dropouts with USB ethernet gadget
  * firmware: imx477: Allow long exposures for the binned modes.
  * firmware: arm_dispmanx: Use ALPHA_MIX flag
  * firmware: power: Refactor the interface to the PMICs
  * firmware: platform: vl805: Get BAR2 address from PCIe BAR2 registers
  * firmware: arm_loader: Return all borrowed DMA channels
* Wed Mar 10 2021 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Fix typo s/pannel/panel/
* Mon Mar  8 2021 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Enable bluetooth over PL011 by default (jsc#SLE-17223)
- Enable VC4 by default on RPi4 (jsc#SLE-12151)
* Wed Jan 27 2021 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Use disable-v3d overlay, it isn't ready for users to use but soon good enough
  for a technology preview. (jsc#SLE-15928)
* Fri Jan 22 2021 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Update to 051e5e1be8 (2021-01-21) (jsc#SLE-16616):
  * firmware: Export bootloader config via device-tree
  * firmware: ISP: Colour denoise
  * firmware: platform: Define DVFS modes and change default to be fixed AVS voltage
  * firmware: arm_loader: Auto-select 64-bit for kernel8.img
  * firmware: hdmi: Throttle auto-i2c register writes to avoid PWM audio underrun
* Fri Jan 15 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to c78f3ef4 (2021-01-15):
  * firmware: isp: Fix handling of different YUV colour spaces
  * firmware: poe_hat: Actually close the I2C handle
  * Firmware: undo previous reverts
  * firmware: Revert firmware: HAT/I2C updates
  * firmware: firmware: MMAL/IL: Add support for the 16bpp Bayer/Grey raw 10/12/14 formats
  * firmware: audioplus: Fix hang when switching destination
    See: #1516
  * firmware: HAT/I2C updates
  * firmware: MMAL/IL: Add support for the 16bpp Bayer/Grey raw 10/12/14 format
  * firmware: dmalib: Keep 40-bit DMA clear of L2 alias
  * firmware: DSI interrupt fixes, and HDMI SM clock for deep colour
* Wed Dec 16 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 8a5549c (2020-12-15):
  * firmware: dmalib: Allow sdcard to borrow channel 6
    See: #1511
    See: Hexxeh/rpi-firmware#251
    See: https://www.raspberrypi.org/forums/viewtopic.php?f=63&t=294932
* Tue Dec 15 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 8cd7665 (2020-12-14):
  * firmware: Use DMA40 for PWM audio
  * firmware: imx477: Replace existing 720p120 mode with a new 1332x990 120fps mode
  * firmware: arm_loader: Allow max_framebuffers=0 to disable framebuffers
    See: #1507
* Wed Dec  9 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Update to 919aee0ed7 (2020-12-08):
  * firmware: Switch DA9121 PMIC to PWM mode when ARM > 600 MHz
  * firmware: xhci: Don't reset BCM2711 XHCI from filesys in start.elf
  * firmware: platform: Avoid vco issue with low arm_freq_min on Pi0-3
* Thu Oct 29 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Remove vl805-firmware-loader overlay as it now reached upstream.
* Thu Oct 29 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 5f95dfda (2020-10-22) - boo#1178262
  * firmware: hdmi: Timeout HDMI EDID reads
  * firmware: arm_ldconfig: Don't invalidate the dcache for most of memory
    See: #1445
  * firmware: arm_loader: Allow arm to see force_turbo and uart boosts
  * bootcode: usb: Fix USB init for 2835 bootcode.bin
  * firmware: arm_loader: Update armstubs with those from PR 117 …
    See: raspberrypi/tools#117
  * firmware: Revert sdcard: Reduce SD read overhead
  * firmware: arm_loader: Add GET/SET_VPU_VECTOR mailbox calls
  * firmware: arm_loader: enable simple_fb iff there is a display
    See: raspberrypi/linux#3878
  * firmware: arm_loader: Mark V3D early boost as for the ARM
    See: #1469
* Thu Oct  1 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to e7464dd (2020-09-30):
  * firmware: platform: Add support for SCB clock and set to 250MHz
  * firmware: Revert arm_loader: Move first call to set_turbo after arm->start
  * firmware: arm_ldconfig: GZIP-compressed ARMv8 kernel support
  * arm_ldconfig: Fix kernel8 decompression See: #1467
  * firmware: arm_ldconfig: Restore the fallback load address See: #1467
  * firmware: ilcamera: Disable timeouts on trigger sink devices
  * firmware: genet: Flush RBUF/TBUF and clear mac-address on stop
    See: raspberrypi/linux#3850
  * firmware: dmalib: Add support for 40-bit 2d memcpy
  * firmware: sdcard: Reduce SD read overhead
  * firmware: sdhost_arasan: Increase time threshold before suspend
  * firmware: video_decode: Only shutdown codec on both ports being disabled …
  * firmware: vc_image_helper: Avoid misaligned exception due to uninitialised pointer
  * firmware: arm_loader: Make arm clock accesses only see their own boosts
    See: #1469
* Wed Sep  9 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Update to baec4d28b (2020-09-03) (bsc#1176202)
  * firmware: Update to latest master
* Tue Aug  4 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Update to bd816dbac (2020-07-31)
  * firmware: Switch to master branch for Pi4 firmware
  * firmware: il: isp: Ensure HR output is active and ISP is open before starting a frame
  * firmware: isp_ctrl: Fail in start_[raw|yuv]_frame if ISP is not idle See:
    https://www.raspberrypi.org/forums/viewtopic.php?f=28&t=275489
* Tue Jul 21 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add vl805-firmware-loader overlay so as for upstream u-boot to be able to
  acess USB.
* Fri Jul  3 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add armstub=armstub8-rpi4.bin entry conditionally for rpi4, if not present in
  boot partition the boot will continue as is.
* Fri Jun  5 2020 Fabian Vogt <fvogt@suse.com>
- Move config tweaks to this package (boo#1172387)
* Wed Apr  8 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add cma-default option to vc4-kms-v3d overlay to mimic the previous default
  behaviour, which used the kernel's default size. For now we still set the CMA
  trough the kernel command line, that will change in the future. (bsc#1167761)
* Mon Apr  6 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Get rid of rpi4-thermal overlay, not needed anymore
- Get rid of rpi4-firmware-dma-ranges overlay, not needed anymore
- Get rid of rpi4-gpio-names overlay, not needed anymore
* Wed Apr  1 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Drop Supplements for extra and extra-pi4
* Tue Mar 31 2020 Petr Tesařík <ptesarik@suse.com>
- Use proper quoting for the modalias Supplements (see also
  https://github.com/openSUSE/libzypp/issues/216).
* Fri Mar 27 2020 Petr Tesařík <ptesarik@suse.com>
- Add a modalias Supplements, so the package gets selected
  automatically on a Raspberry Pi.
* Thu Mar 26 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Remove rpi4-cma overlay, not needed anymore (bsc#1167761)
* Fri Mar 20 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add rpi4-firmware-dma-ranges overaly which fixes touch input on the official
  7" display (bsc#1167147)
* Wed Mar 11 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add uboot-bcm2835-pl011 overlay, which fixes the serial port compatible name
  as expected by u-boot, relevant for RPi, RPi2 and RPi0 families (bsc#1166414)
* Fri Feb 28 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add rpi4-gpio-names overlay so as to have a consistent way to access GPIOs (bsc#1164722)
* Thu Feb 27 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Remove rpi4-pcie-ib-size-fix as raspberrypi-firwamre-dt removed it (bsc#1165143)
* Fri Feb 21 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Update to f4b5869 (2020-02-12) (bsc#1163476):
  * firmware: board_info: Fix GPIO expander reset trait
  * firmware: gencmd: Fix measure_clock name for CLOCK_OUTPUT_108
  * firmware: platform: Compromise on gpu overclock settings
- After the rpi-5.5.y update in raspberrypi-firmware-dt:
  * Remove rpi4-genet as it's not needed anymore
  * Remove gpu_mem entry for rpi4
* Wed Jan 22 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to be2713bed4 (2020-01-16):
  * firmware: master: arm_ldconfig: Support multiple initramfs files
    See: #1318
  * firmware: power: Make pmicrd/pmicwr available to all
  * firmware: arm_ldconfig: Support multiple initramfs files
    See: #1318
  * firmware: Add support for backlight enable
  * firmware: Revert mmal: Support 64 bit clients
    See: raspberrypi/userland#586
  * firmware: arm_dt/dtoverlay fixes for ARM side camera driver power control
  * firmware: Fixup for vcgencmd display_power
    See: #1224
  * firmware: Add hdmi_wifi_pixel_freq_adj config option
* Mon Jan 20 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add rpi4-thermal device tree overlay for RPi4 (bsc#1160311)
* Thu Jan  9 2020 Matthias Brugger <mbrugger@suse.com>
- Disable overscan by default (bsc#1160473)
* Thu Dec 19 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0c01dbefba (2019-12-11):
  * firmware: platform: Allow fixed voltage with avs_disable=1
  * firmware: EMMC: Use PLLD for EMMC for 250MHz host-clock
    See: #1289
  * firmware: platform: Round down effective frequencies when they exceed max
    See: #1290
  * firmware: arm_loader: Pass video mode via kernel command for composite
    See: #1285
  * firmware: Fix lens shading table generation buglet
    See: https://www.raspberrypi.org/forums/viewtopic.php?f=43&t=190586&start=75#p1534672
  * firmware: hdmi: Use RB2 timing for 2560x1440@60 if pixel clock is 241.5 MHz
  * firmware: arm_dt: Look for ethernet0 before ethernet
  * firmware: arm_dt: Set PCIe dma-ranges from memory size
  * firmware: hdmi: HDMI SM clock must not run slower than audio MAI clock …
    See: #1295
  * firmware: arm_loader: Pass video mode via kernel command for composite (master)
    See: #1285
  * firmware: power: Use Pi4 PMIC values on Pi3+
  * firmware: Fix filtered handling of array variables
    See: #1296
  * firmware: Update libfdt to v1.5.1+
    See: raspberrypi/userland#582
  * firmware: dtoverlay: Extend DT parameter syntax
  * firmware: memorymap: Include FW revision in start.elf
* Wed Dec  4 2019 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add custom gpu_mem config for RPi4 (bsc#1158406)
* Wed Nov 27 2019 Matthias Brugger <mbrugger@suse.com>
- Load rpi4-genet-overlay to fix the compatible for the network device (jsc#SLE-7771)
* Tue Nov 26 2019 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Enable rpi4-cma dt overlay to properly setup CMA on that platform (SLE-7771)
- Enable rpi4-pcie-ib-size-fix dt overlay to properly setup PCIe on that
  platform (SLE-7771)
* Tue Nov 26 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 6e4a7232c (2019-11-19):
  * firmware: platform: Differentiate between boostable and turbo clocks
  * firmware: arm_dt: Set WL_ON and BT_ON from .dtb
  * firmware: Fixup chosing of bit depth in legacy graphics
    See: raspberrypi/linux#3331
  * firmware: vec: Setup WideScreen Signalling outside of copy protection
    See: https://www.raspberrypi.org/forums/viewtopic.php?f=28&t=256489
  * firmware: Add global reset mailbox
  * firmware: 2711: De-couple start.elf clock setup from the bootloader
  * firmware: scaler: Correct defines for SCALER_POS0_START_Y_[MASK|SHIFT] (HVS4)
  * firmware: platform: Fix missing HDMI PHY power down bit
  * firmware: Reduce voltage as part of DVFS
  * firmware: arm-loader: Inherit 2711 mac-address from the bootloader
    See: http://git/vc4/vc4/merge_requests/687
  * firmware: arm_loader: Respect all required frequencies when throttling
  * firmware: Fixup vcgencmd display_power return values
* Mon Nov 25 2019 Matthias Brugger <mbrugger@suse.com>
- If booting RPi in arm64 mode or not will be set by u-boot through
  ubootconfig.txt. This allows to build u-boot for RPi3/4 with 32-bit.
* Fri Nov 15 2019 Matthias Brugger <mbrugger@suse.com>
- config changes for RPi3:
  * delete upstream-aux-interrupt as not present anymore
  * set arm_control for RPi3 only
  * add RPi3 overlays
* Mon Nov 11 2019 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- disable vc4 on RPi4 using the disable-vc4.dtbo devicetree overlay (SLE-7771)
* Wed Nov  6 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 8e688a443 (2019-11-06):
  * firmware: Unicam: Request frequency of 250MHz when running camera use cases
  * firmware: arm_loader: Fix UART unmapping
  * firmware: uart1: Revert to the old core-frequency-locking method
    See: #1267
  * firmware: arm_loader: Provide a sensible device_tree_end default
    See: #1259
  * firmware: mmal_ril: Fix size reported on ENOSPC error
    See: #1269
  * firmware: hvs: Trigger the EOLn timer at the field rate when interlaced
    See: #1227
  * firmware: bootloader_state: Add support for a custom TFTP prefix parameter
  * firmware: arm_loader: GIC stub => 2711 stu
    See: #1255
  * firmware: arm_loader: Add os_prefix option
    See: raspberrypi/linux#3237
  * firmware: Add support for arbitrary memory specification
  * firmware: arm_loader: Fix explicit kernel name handling
    See: #1277
  * firmware: Added a new display power mailbox call
  * firmware: Update display_power gencmd with optional display id
    See: raspberrypi/linux#3050
  * firmware: Remove legacy pkgconfig to avoid Mesa conflicts
    See: raspberrypi/userland#585
  * firmware: Update display_power gencmd with optional display id
  * firmware: sysman: Fix unsafe check for h264 being enabled
    See: popcornmix/omxplayer#749
  * firmware: platform: Reduce absolute microvolts threshold to 500000
  * firmware: Loop to init hotplug
* Fri Oct  4 2019 Matthias Brugger <mbrugger@suse.com>
- add RPi4 config options
* Wed Oct  2 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to a16470ad4 (2019-09-30)
  * firmware: platform: Set up emmc clock earlier
  * firmware: hdmi: Implement platform_display_power on 2711
    See: #1224
  * firmware: arm_loader: Pass overscan settings to the kernel
  * firmware: arm_loader: Add option disable_fw_kms_setup to stop FKMS setup by FW
  * firmware: hdmi: Use pixel clock multiplier to determine the core clock
  * firmware: Fixups for composite output mode
    See: #1223
  * firmware: platform: Allow display_power to be queried from gencmd
    See: #1224
  * firmware: arm_loader: Fix no-DT and upstream handling
    See: #1250
  * firmware: Round up HDMI0 minimum core clock
  * firmware: board_info: Support bcm2710- and bcm2837- Pi 2 DTBs
    See: raspberrypi/linux#3234
  * firmware: power: bcm2711: Rescale the GPIO pad power
  * firmware: brfs: Add GENET driver for 2711
  * firmware: bootloader_state: Add network state and bootmode configuration
  * firmware: bootloader_state: Fix mask for EEPROM header magic
  * firmware: arm_loader: Fix initial_turbo getting stuck
    See: #1005
  * firmware: ldconfig: Support [edid=*] to mean any HDMI monitor
    See: #1136
  * firmware: image_fx: Remove restriction that output stride must match input stride
  * firmware: image_fx: Remove spamming log line
  * firmware: platform: Switch to divide by one when arm_freq exceeds 2GHz
  * firmware: Add EMMC support to 2711 Arasan EMMC driver
  * firmware: arm_loader: Use /memory@0 if found
    See: raspberrypi/linux#3244
  * firmware: bootloader_state: Fix length for bootloader_config
  * firmware: arasan_emmc: Fix STB_GPIOOVERRIDE for MMC1 in network boot
  * firmware: bfs: Verify that eth FS has not been closed before using
* Mon Sep 16 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Do not run %%preun scripts on upgrade (boo#1150408)
* Thu Sep  5 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to e2e17cd03 (2019-09-04)
  * firmware: Port file loading revamp to master
  * firmware: Avoid defaulting to 64-bit kernel on older Pi
  * firmware: Revamp file loading logic
  * firmware: power: Allow reading uncached voltage
  * firmware: arm_loader: Request KMS to use CVT timings
  * firmware: vc_image: Default YUVUV to non-tall mode, with flag if required
  * firmware: ldconfig: Implement [pi2/pi3/pi3+] using board types
    See: #1242
  * firmware: platform: Remove 10mV of margin
  * firmware: power: Add 2711-specific PMIC compensation values
  * firmware: sdhost_arasan: Disable busy wait on EMMC_STATUS_NEW_CARD_DATA_SET
  * firmware: AWB: Fix for manual WB settings in capture
    See: #1215
  * firmware: arm_loader: Use platform_get_min_core_voltage for actual min voltage
  * firmware: clock: Remember disable state across clock changes
  * firmware: platform: pi4: Reduce min core voltage to 810mV
  * firmware: arm_dt: Use boost to force turbo mode rather than modifying core_freq_min for uart
  * firmware: arm_loader: Add optional flag to add_boost and get_boost calls
  * firmware: avs_2711: Move margin from init structure to run time
  * firmware: platform: fix get_min_default
  * firmware: arm_loader: Use AP_CLOCK_T for clock_iterator for easier debugging
  * hdmi: Switch to active pixel rate + margin for core clock boost
  * platform: Reduce the minimum core clock frequency from 250 to 200 MHz
  * firmware: arm_loader: Fix initial_turbo getting stuck
    See: #1005
  * firmware: clock_2711: don't set reserved values for KA in PLL KAIP registers
  * firmware: AWB: Allow user to set manual gains for the RPi algorithm
  * firmware: arm_loader: Fix disabling of audio before reboot
  * firmware: fixed up the custom CVT values to use correct group
  * firmware: hdmi: Add independent table entries for hdmi_timings on each display
    See: #1218
  * firmware: Fix to allow HDMI audio port route setting
    See: raspberrypi/linux#3100
  * firmware: pwm_audio: Use the correct DREQs on Pi4
    See: #1214
  * firmware: pixelvalve_2711: Alter back porch for widths of 1366
    See: #1202
  * firmware: Clear the SMIDSW1 display interrupt flag on startup
  * firmware: dt-blob: Declare Pi 4B's SD_IO voltage selector
  * firmware: Fixups for missing code changes from Pi4 branch
    See: #1201
  * firmware: Change order of display remapping for default display number
  * firmware: AWB: Set default number of stats regions for RPi AWB
    See: #1198
  * firmware: Fix composite interrupt HVS channel
  * firmware: scalarlib: Fix width setting for SCALERLIB_PIXEL_FORMAT_YUV10COL
  * firmware: vcmailbox: Add a new SET_AUDIO_LDO_STATE mailbox command
  * firmware: Add mailbox call to report the HDMI timings
  * firmware: H264: Set the decoder cache AXI burst length to the same as the encoder
  * firmware: gencmd: Fix gencmd max result length
  * firmware: bootloader_config: New gencmd to read the EEPROM config
  * firmware: pwm_audio: Use PWM1 on BCM2838 unless remapped
    See: #1178
  * firmware: AWB updates
    See: #1167
  * firmware: dispmanx: Fix handling of disable_overscan to not disable it totally
    See: raspberrypi/linux#3059
  * firmware: power: Enable/disable H264 and ISP clocks with domain
  * firmware: arm_loader: arm_64bit=0 should disable loading of kernel8.img
  * firmware: dt-blob: CM has no activity LED
* Wed Jul 10 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix %%post scripts to copy RPi4 firmware files too
- Add %%preun to remove files from EFI partition
- Move Pi4 debug firmware to its own package extra-pi4 due to
  limited size on EFI partition
* Wed Jul 10 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 025759b8 (2019-07-09):
  * firmware: hvs: Emulate the EOLn interrupt with a timer reset from VSTART
    See: #1154
  * firmware: Add support for Rec2020 colour space in vc_image, IL, and MMAL
  * firmware: Fix composite mode on devices up to Pi3B+
    See: #1166
  * firmware: Fixes for core_freq_min causing failure on HDMI1
    See: http://git/vc4/vc4/merge_requests/529
  * firmware: hdmi: Don't release previous boost until mode set is complete
    See: #1159
  * firmware: bcm_host: Adjust for 64-bit physical addresses
    See: #1161
  * firmware: arm_loader: Shrink most stubs back to 256 bytes, add arm64 GIC stub
    See: raspberrypi/linux#3032
  * firmware: arm_dispmanx: Add support for setting the colour encoding
  * firmware: dmalib: Fix Lite channel interrupt usage, and macro name
  * firmware: Force overscan off when using LCDs
    See: #1173
  * firmware: cec: Fix crash when using CEC with HDMI1
  * firmware: arm_display: Fix race condition initialising CEC
  * firmware: hdmi: Always use boost frequency for initial mode set
    See: #1159
  * firmware: AWB: Fix usage for IR operation
    See: #1167
  * firmware: arm_loader: Support CLOCK_EMMC2 from GET_CLOCK_RATE
    See: #1179
  * firmware: arm_loader: Force word alignment for the DTB
    See: #1175
  * firmware: clock_2711: don't set reserved values for KA in PLL KAIP registers
  * firmware: Assorted minor fixes for tvservice -o
  * firmware: Rename hdmi_enable_4k to hdmi_enable_4kp60
  * frimware: Revert: clock_2711: don't set reserved values for KA in PLL KAIP registers
* Wed Jun 26 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to d786b62 (2019-06-25):
  * firmware: Fix AWB exception bug
  * firmware: Updates for Pi4
  * firmware: 2711: CORE, EMMC & BVB clock updates for WiFi / 4Kp60
  * firmware: 711: Use boost instead of fixed freq for 4Kp60
* Wed Jun  5 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to e289f6a59 (2019-05-28):
  * firmware: smservice: Avoid a double free
  * firmware: arm_loader/display: All the framebuffer allocation to be made on the ARM
  * firmware: isp_tuners: Fix memory leak in error path
  * firmware: testc: Fix dps parsing
  * firmware: camera_subsystem: Fix hardware sync pulses off disable_camera_led
  * firmware: Replace the remaining direct users of C(mask_gpu_interrupt[0|1])
  * firmware: arm_display: Kick transposer for the rainbow screen if required
  * firmware: dispmanx: Do not allow transpose if using Full KMS
    See: raspberrypi/linux#2891
  * firmware: Revert: arm_loader/display: All the framebuffer allocation to be made on the ARM
  * firmware: arm_loader: Further conditionals for passing in a frame buffer
  * firmware: di_adv: Drop back to fast if QPUs are masked off
* Fri Mar  8 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to fd15e070 (2019-03-08):
  * firmware: raspivid: Stop --raw option resetting --raw-format to YUV
    See: https://www.raspberrypi.org/forums/viewtopic.php?f=43&t=189830&start=25#p1432589
  * firmware: Fixed up overflow in microsecond timer
    See: raspberrypi/userland#535
  * firmware: camera_subsystem: Clean up disable_camera_led handling
  * firmware: smservice: Add defines for VPU allocations
  * smservice: Add support for reporting the supported version to the host
  * firmware: Camplus: cdi: Remove requirement for calibration functions
  * firmware: isp: Reinstate lres shift parameter accidentally dropped with gamma changes
    See: #1108
  * firmware: mmal_ril: List all 4 Bayer orders if the IL component says it supports Bayer
  * firmware: camera/image_encode: Add timestamp to frames encoded with image_encode
    See: raspberrypi/linux#2351
* Thu Jan 31 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 81cca1a (2019-01-22):
  * firmware: Added ability to have an third transpose buffer
    See: #837
  * firmware: isp: Correct the conversion tables changed in adding the gamma block
    See: #1084
  * firmware: raspberrypi_full variant: Drop unused Camplus sw stages
  * bootcode: Reset WiFi and BT devices before resetting the expander
    See: #1088
  * bootcode: Fix Ethernet boot on a different subnet
    See: #1078
  * firmware: interface: Drop vcfiled
    See: raspberrypi/userland#525
  * firmware: Add reference counting to the local audio players
    See: #547
  * firmware: arm_loader: Add reporting the firmware git hash via the mailbox
  * firmware: vcos: Add reporting of which variant was built
    See: raspberrypi/linux#2806
  * firmware: Update vcdbg help
    See: #594
* Tue Jan  8 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to e1bd9b0 (2018-12-21):
  * firmware: Added a mailbox function for setting gamma
  * firmware: bootcode: Support parsing of gpio filters from config.txt
    See: #1076
  * firmware: video_encode: Allow Inline Headers to be changed whilst active
  * firmware: IL: Add XRGB8888 and XBGR8888, and support on video_render, isp, and hvs
  * firmware: image_encode: Allow arbitrary buffer strides matching the appropriate multiples
  * firmware: platform: Use 3aplus dt-blob section and bcm2710-rpi-3-a-plus.dtb
  * firmware: dispmanx: Also apply overscan_scale when clamping to screen
    See: https://forum.kodi.tv/showthread.php?tid=338052
  * firmware: arm_dt: Accept "csi" as a special DT node that masks IRQs
  * firmware: MMAL: Include OPAQUE in the list of supported encodings where appropriate
    See: https://www.raspberrypi.org/forums/viewtopic.php?f=67&t=226416
  * firmware: video_render: asserting on the buffer being unlocked is invalid
  * firmware: video_render: Further fix to a vcos_verify
  * firmware: IL hvs: Fail component create if the HVS or TXP interrupts are masked
  * firmware: Clean up masked interrupt handling - moves it to intctrl
  * firmware: vcinclude: Clean up INTERRUPT_xxx defines to use one place
  * firmware: vcfw: camera_subsystem: Stop cameras being detected if ARM has Unicam instance
  * firmware: vc_image: Fix up vc_image_bits_per_pixel for YUYV variants and BGR888
  * firmware: vc_image: Make the alternate path in yuv420 to rgb888 support bgr888
  * firmware: vc_image: Add an rgb_stripe_swap_ext which takes pitches
  * firmware: vc_image_convert: yuv420 to bgr888 failed on (width&31) != 0
  * firmware: IL isp: Use gamma block to shift 10bpp YUV to the correct pipe depth
  * firmware: video_encode: Always set the input port nBufferSize to match the image
  * firmware: Camera/ISP: Allow option to disable demosaicing
* Fri Nov 30 2018 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Removed upstream-mmc and rpi3-hdmi overlays as not needed anymore
- Added Conflicts statement to avoid issues with older kernels
* Tue Nov 20 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 55e591283 (2018-11-05):
  * firmware: Move to driver based backlight
    See: #1063
  * bootcode: Extend TEST_UNIT_READY timeout to 20 seconds,
    some hard drives take a really long time
    See: #898
  * firmware: video_render: Treat an empty buffer with ENDOFFRAME set as
    a flush
  * firmware: dispmanx: Add option to ignore all layers lower than the
    current layer
* Wed Oct 17 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 10c1c5f96 (2018-10-15):
  * firmware: jpeg/mjpeg: MJPEG doesn't insert JFIF APP0 header
    See: https://github.com/raspberrypi/userland/issues/345
  * firmware: Add IL HVS component
  * firmware: mmal: Acquire zero copy buffers on being passed to the VPU
  * firmware: video_render: Use per pixel alpha on RGBA and BGRA
  * firmware: video_render: Add support for alpha options (MIX and PREMULT)
  * firmware: video_encode: Use default values on invalid nStride or nSliceHeight
    See: https://github.com/raspberrypi/firmware/issues/1051
  * firmware: gpioman/FXL6408: Handle open failing sensibly
    See: https://github.com/raspberrypi/firmware/issues/1053
  * firmware: Delay backlight coming on
    See: https://github.com/raspberrypi/firmware/issues/1052
  * firmware: LCD driver close fixes
  * 2ndstage: ignore autoboot.txt if boot partition is already set
    See: https://github.com/raspberrypi/noobs/issues/508
  * firmware: 2ndstage: Report IP address in ARP response in network order
  * firmware: video_decode: Fix error in previous memory leak patch
  * firmware: video_encode: Add ISP conversion support for RGBX32
  * firmware: platform: Also report soft temperature limit in get_throttled bits
  * firmware: IL isp: minor code cleanups
  * firmware: image_encode: Support Video domain on input port
  * firmware: Camplus: annotate: Check lines_available >= lines_required
    See: https://github.com/raspberrypi/userland/issues/485
  * firmware: arm_dt: Work around an absent cache-line-size
    See: https://github.com/raspberrypi/linux/issues/2643
  * firmware: rawcam: Fix double buffer return issue
  * firmware: rawcam: Code cleanup
  * firmware: host_apps: Fixup partially merged commit from userland
    See: https://github.com/raspberrypi/firmware/issues/1027
  * firmware: mmal: Add KEEP_PORT_FORMATS flag to mmal connection
    See: https://github.com/raspberrypi/userland/pull/483
  * firmware: RaspiStill: Apply gpsd info as EXIF tags
    See: https://github.com/raspberrypi/userland/pull/286
  * firmware: video_encode: Drop back to software conversion if stride is not mod32
    See: https://github.com/Hexxeh/rpi-firmware/issues/182
  * firmware: arm_dt: Break out GPIO save/restore from HAT code as needed for PoE
* Thu Aug 16 2018 guillaume.gardet@opensuse.org
- Update to 953a3396 (2018-08-10):
  * firmware: MMAL/IL: Fix for reducing alignment patch
    See: https://www.raspberrypi.org/forums/viewtopic.php?f=43&t=62364
  * firmware: Added a dpi_timings config item
  * firmware: Add DPI Driver default settings
  * firmware: HVS channel should come from the DISPLAY_INFO
* Wed Jul 11 2018 guillaume.gardet@opensuse.org
- Update to d3c3d031 (2018-07-09):
  * firmware: pwm_sdm: fix an edge case when reading back DMA
    source addresses
  * firmware: pwm_sdm: fix write handle refcounting
  * firmware: arm_loader: Update NOTIFY_REBOOT to reset the GPIO
    expander
  * firmware: Allow selection of DSI port for LCD
  * firmware: dtoverlay: More "reg" and "name" support
  * firmware: imx219: Updates for production test
  * firmware: variant: Disable custom_preproc and focus_stats_preproc
    camera stages
  * firmware: bootcode: Force an I2C stop as a reset
  * firmware: power: Ensure at least 2ms between writes to the PMIC regs
  * firmware: power: Add 3ms threshold
  * firmware: power: Reduce i2c speed of pmic to 100kHz
* Thu Jun  7 2018 guillaume.gardet@opensuse.org
- Update to ab802d3 (2018-06-03):
  * revert: sdram: Reduce address skew from -10 to -5
  * sdram: Reduce address skew from -10 to -5
  * platform: Avoid improving the schmoo on Pi3+
  * platform: Latest AVS rules
  * sdram: Increase read/write latency for higher sdram frequencies
  * power: Add boot-time 3b+ PMIC register logging
  * power: Continue to probe PMIC after error
  * Match phy setup same as bootcode for device mode initialisation
  * Add logging_messages to UART
  * Fix 3B+ bootcode.bin only booting
  * video_encode: Filter the list of encoders based on variant
  * mmal: Relax requirement on a buffer in mmal_port_send_buffer
  * platform: avs: Also apply chicken bits to boost voltage
* Thu May 24 2018 fvogt@suse.com
- Allow u-boot to set arm_control to support 32-bit images on RPi3
* Fri Apr 20 2018 guillaume.gardet@opensuse.org
- config: replace dtoverlay=vc4-kms-v3d and dtoverlay=dwc2 by
  dtoverlay=upstream, this fix gfx for RPi1-256M version
* Thu Apr 19 2018 guillaume.gardet@opensuse.org
- Update to a154f21 (2018-04-16):
  * Partial revert for eemc clock change for slice
  * config: Add gpio command
  * hat_lib: Only probe HAT EEPROM if ID pins are inputs
  * Added a arm_display_kick function
  * Possible fix for HDMI audio pause
  * arm_loader: Always set the turbo frequencies immediately
* Thu Apr  5 2018 agraf@suse.com
- Allow user defined config options (bsc#1088356)
- Move HDMI workaround to rpi3 section (fixes RPi2 HDMI output)
* Wed Mar 14 2018 agraf@suse.com
- Update to 3347884 (2018-03-13)
  - Add support for new RPi3 B+ (bsc#1085262)
* Mon Feb 19 2018 agraf@suse.com
- Add overlays to match previous U-Boot provided DT
- Add Recommends: on dt and config packages
* Fri Feb 16 2018 agraf@suse.com
- Update to 445b6a8 (2018-02-09)
* Wed Jan 31 2018 jengelh@inai.de
- Avoid bashisms in %%post
* Mon Jan 22 2018 agraf@suse.com
- Merge config.txt files into a single config.txt with subsections
- Set GPU memory usage to 32MB, this is enough for vc4 (boo#1074566)
- Update to 050175d (2018-01-17)
* Sat Nov 25 2017 afaerber@suse.de
- Add rpi0w sub-package and config (boo#1069828). Derived from rpi3.
- Update to abfb4be3e1 (2017-11-17)
* Thu Oct 12 2017 guillaume@opensuse.org
- Update to a88e126a (2017-10-11)
* Wed Aug 23 2017 guillaume@opensuse.org
- Update to 8fe001e (2017-08-22)
* Wed Apr 19 2017 afaerber@suse.de
- Update to b038854 (2017-04-04)
* Mon Feb 20 2017 malcolmlewis@opensuse.org
- Update to 2b495ac (2017-02-20)
* Thu Jan 12 2017 guillaume@opensuse.org
- Update to e44f66a (2017-01-10)
* Fri Nov 18 2016 guillaume@opensuse.org
- Update to 64996b0 (2016-11-16)
* Tue Oct 25 2016 guillaume@opensuse.org
- Update to 4a0e54e (2016-10-20)
* Wed Oct 12 2016 guillaume@opensuse.org
- Update to a021d6e (2016-10-11)
* Tue Sep 27 2016 guillaume@opensuse.org
- Increase from 64 MB to 96 MB of RAM for GPU for RPi with 256 or
  512 MB of RAM to be able to decode a 1080p h264 video in kodi
* Tue Sep 27 2016 guillaume@opensuse.org
- Update to ad8608c (2016-09-21)
* Thu Sep 15 2016 fvogt@suse.com
- Use "avoid_warnings=1" in config-rpi{,2,3}.txt (bsc#998973)
* Mon Sep 12 2016 afaerber@suse.de
- Clean up config-{rpi2,rpi3}.txt, dropping rpi1 defaults
  * On the rpi1 Model B rev. 2 performance results are similar
  with and without defaults, so in doubt leave our settings in
  config-rpi.txt until proven the defaults work better somewhere.
* Tue Sep  6 2016 fvogt@suse.com
- Use default frequencies in config-rpi{2,3}.txt (bsc#989511)
  * Defaults work well on rpi2
  * Allow much higher frequencies on rpi3
* Fri Sep  2 2016 afaerber@suse.de
- get-from-git.sh: Update for -config-rpi* sub-packages
- Update to 334f548 (2016-09-02)
- Add post-install scripts to copy files to /boot/efi where needed.
  /boot/vc may be the mountpoint for boot.scr based installations
  or a symlink to /boot/efi. (bsc#996064)
* Wed Aug 24 2016 mpluskal@suse.com
- Update to d0bc6ce (2016.08.23)
* Thu Jul 21 2016 mpluskal@suse.com
- Update to 051aed7 (2016.07.15)
- Simplify spec file a bit
* Thu Jun 16 2016 afaerber@suse.de
- Fix last changelog entry
- Run format_spec_file in pre_checkin.sh to fix spec file header
- Restore silently dropped defattr that breaks older builds
* Mon Jun  6 2016 dmueller@suse.com
- remove branding-openSUSE subpackage and split config
  into the 3 variants for (rpi, rpi2, rpi3)
* Tue May 31 2016 guillaume@opensuse.org
- Update to ac0c0bf (2016-05-20)
* Tue May 10 2016 dmueller@suse.com
- mark package as noarch (adds rpmlintrc)
- split extra bootloaders into separate -extra subpackage
* Wed May  4 2016 afaerber@suse.de
- Enable aarch64 builds for Raspberry Pi 3
* Fri Apr 29 2016 guillaume@opensuse.org
- Update to 20958cd (2016-04-27)
* Wed Apr  6 2016 guillaume@opensuse.org
- Update to c065500 (2016-04-05)
* Mon Mar  7 2016 afaerber@suse.de
- Revert to last actual change b48c36f (2016-03-04)
- Fix version bug found by Guillaume by using git-log (as intended)
* Mon Mar  7 2016 guillaume@opensuse.org
- Update to 845eb06 (2016-03-05)
* Mon Mar  7 2016 guillaume@opensuse.org
- Fix get-from-git.sh to get version even when packaged files are
  not in the last commit
* Tue Mar  1 2016 guillaume@opensuse.org
- Update Config.txt (add GPU mem option for 1024 MB version)
* Tue Mar  1 2016 guillaume@opensuse.org
- Update to 9cd1c6c (2016-02-29)
* Thu Feb 25 2016 guillaume@opensuse.org
- Update to 565197e (2016-02-19)
* Thu Feb  4 2016 guillaume@opensuse.org
- Update to cb2ffaa (2016-02-01)
* Thu Jan 14 2016 guillaume@opensuse.org
- Update to 7147575 (2016-01-13)
* Tue Dec  8 2015 afaerber@suse.de
- Update to 224c756 (2015-12-08)
* Tue Dec  8 2015 afaerber@suse.de
- Move files from /boot to /boot/vc to allow directly updating the
  FAT partition through a /boot/vc mount
- Require the main package for the branding package
* Sun Nov 29 2015 afaerber@suse.de
- Update to ed611df (2015-11-25)
  * Clarifies licensing of start_*.elf files
- Improve get-from-git.sh
  * Automate file removal and addition
  * Use date of last relevant change
- Add branding-openSUSE subpackage, based on a to-do item in
  openSUSE:Factory:ARM JeOS package's uboot-image-install.in script
  * Update comment about zImage to reflect current U-Boot situation
* Wed Oct 28 2015 afaerber@suse.de
- Add get-from-git.sh script as source file (sr#341314)
* Mon Oct 26 2015 afaerber@suse.de
- Update to 4047fe2 (2015-10-23)
- Throw out all non-free gfx sub-packages and files
* Mon Oct 12 2015 guillaume@opensuse.org
- Update to ba7a8fb (2015-10-11)
* Mon Aug 17 2015 guillaume@opensuse.org
- Update to e1e2823 (2015-08-15)
* Fri Aug 14 2015 guillaume@opensuse.org
- Update to c25cc51 (2015-08-13)
* Mon Jul 20 2015 guillaume@opensuse.org
- Update to cf20cb2 (2015-07-17)
* Tue Jun 23 2015 guillaume@opensuse.org
- Update to e8f6e12 (2015-06-22)
* Thu Jun  4 2015 guillaume@opensuse.org
- Update to 16044ee (2015-06-02)
* Mon Feb 16 2015 guillaume@opensuse.org
- Add %%{_bindir}/raspividyuv
* Mon Feb 16 2015 guillaume@opensuse.org
- Update to 8aca576 (2015-02-14)
* Tue Feb 10 2015 bill@merriam.net
- Update spec file to change ExclusiveArch to %%arm to support the ARMv7 RPi
* Wed Nov  5 2014 guillaume@opensuse.org
- Update to 0080d30 (2014-11-04)
* Thu Oct 16 2014 guillaume@opensuse.org
- Update to e4afeda (2014-10-12)
* Wed May 14 2014 bwiedemann@suse.com
- Update to c0319ac (2014-05-13)
* Wed Oct 30 2013 guillaume@opensuse.org
- Add "Provides: libEGL.so.1 libGLESv1_CM.so.1 libGLESv2.so.2" to
  fix libs deps
* Tue Oct 29 2013 guillaume@opensuse.org
- Fix Mesa conflicts for EGL, GLESv1 and GLESv2 libs
* Tue Oct 29 2013 guillaume@opensuse.org
- Update to 4c14569 (2013-10-18)
* Mon Sep  9 2013 guillaume.gardet@opensuse.org
- Move bins and libs to standard path (/usr/*) so remove /opt/vc/lib
    from lib search path (keep symlinks in /opt/vc for compatibility
    purpose)
* Sun Sep  8 2013 seife+obs@b1-systems.com
- Update to f6bb324 (2013-09-07)
- add script to fetch tarball from git
- add /opt/vc/lib to library search path so that demo apps in
  raspberrypi-gfx actually work
* Thu Jul  4 2013 guillaume@opensuse.org
- Update to ca5f9c4 (2013-07-02) and now use hardfp
* Wed Jul  3 2013 guillaume@opensuse.org
- Enable build for armv6l
* Mon Apr  8 2013 lars@linux-schulserver.de
- Update to baa3ecffe6 (2013-04-08):
  + ALSA fix to improve mame audio.
  + Add camera demo apps.
  + Removed unnecessary executable bits in documentation
  + improved README
* Sun Dec 30 2012 bwiedemann@suse.com
- Update to 76d0ac3 (2012-12-28) to support 512MB RAM
* Thu Oct 25 2012 guillaume@opensuse.org
- Update to 14a55da (2012.10.21) and add support to GFX
* Fri Oct 19 2012 bwiedemann@suse.com
- rename output to raspberrypi-firmware to be consistent
* Sun Aug 12 2012 bwiedemann@suse.com
- initial package from
  https://github.com/raspberrypi/firmware/ cb9513f
